# img_prc

Description. 
The package img_prc is used to:
prc:
	- Histogram macthing 
	- Structural similarity
	- Resize Imame
ut:
	- Read image
	- Save image
	- Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install img_prc

```bash
pip install img_prc
```

## Author
Adieverson Silva

## License
[MIT](https://choosealicense.com/licenses/mit/)